//****************************************************************************
//	
//	Copyright 2018 by WinSystems Inc.
//
//****************************************************************************
//
//	Name	 : setvolt.cpp
//
//	Project	 : PCM-MIO Console Application
//
//	Author	 : Paul DeMetrotion
//
//****************************************************************************
//
//	  Date		  Rev	                Description
//	--------    -------	   ---------------------------------------------
//	03/09/18	  1.0		Original Release
//
//****************************************************************************

#include <stdio.h>
#include <stdlib.h>  
#include <tchar.h>  
#include <windows.h>
#include "pcmmiodaDLL.h"

#define MAJOR_VER   1
#define MINOR_VER   0
#define DEVICE      1

void print_usage_and_exit(void)
{
    printf("Usage error:\n");
    printf("  setvolt <channel number>\n");
    printf("  Channel must be between 0 and 7\n");
    printf("  If no channel entry, default is ch 0\n");
    exit(1);
}

int _tmain(int argc, _TCHAR* argv[])
{
    int channel = 0; // default channel
    float voltage;
    int dllReturn = SUCCESS;

    printf("PCM-MIO Application : setvolt\n");
    printf("Version %d.%d\n\n", MAJOR_VER, MINOR_VER);

    if (argc > 2)
        print_usage_and_exit();
    else if (argc == 2)
    {
        channel = _ttoi(argv[1]); // change channel if one specified on command line

        if (channel < 0 || channel > 7)
            print_usage_and_exit();
    }

    dllReturn = InitializeSession(DEVICE);

    if (dllReturn)
    {
        printf("Error initializing device.\n");
        exit(dllReturn);
    }
    else   
    {
        printf("Device opened.\n");
    }

    // step through voltages from -10V to 10V
    for (voltage = -10.0; voltage <= 10.0; voltage++) {
        dllReturn = DacSetChannelVoltage(DEVICE, channel, voltage);

        if (dllReturn)
        {
            printf("Error setting DAC channel %d voltage.\n", channel);
            exit(dllReturn);
        }
        else
        {
            printf("DAC Channel %d voltage set to %.5f.\n", channel, voltage);
            Sleep(2000); // sleep for two seconds
        }

    }

    dllReturn = CloseSession(DEVICE);

    if (dllReturn)
    {
        printf("Error closing device.\n");
        exit(dllReturn);
    }
    else
    {
        printf("Device closed.\n");
    }

    return(0);
}
